@@ -15,11 +15,11 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with PyX; if not, write to the Free Software
+# along with PyTone; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from __future__ import nested_scopes
-import ConfigParser, curses, sys, getopt, exceptions, os.path, types
+import ConfigParser, curses, sys, getopt, exceptions, os.path, types, re
 import version
 
 
@@ -280,6 +280,11 @@ class configpath(configitem):
     def _convert(self, s):
         return os.path.expanduser(s)
 
+class configre(configitem):
+    def _convert(self, s):
+        return re.compile(s)
+
+
 BORDER_TOP = 1
 BORDER_BOTTOM = 2
 BORDER_LEFT = 4
@@ -321,6 +326,7 @@ class configborder(configitem):
 
 class general(configsection):
     logfile = configpath("~/.pytone/pytone.log")
+    songchangecommand = configstring("")
     playerinfofile = configpath("~/.pytone/playerinfo")
     dumpfile = configpath("~/.pytone/pytone.dump")
     debugfile = configpath("")
@@ -332,25 +338,36 @@ class general(configsection):
     autoplaymode = configalternatives("off", ["off", "repeat", "random"])
 
 class database(configsection):
+
     class main(configsection):
         type = configalternatives("local", ["local", "remote"])
         basename = configpath("~/.pytone/mp3")
+        dbenvdir = configpath("~/.pytone/mp3")
         dbfile = configpath("")
+        cachesize = configint("1000")
         musicbasedir = configpath("")
+        tracknrandtitlere = configre(r"^\[?(\d+)\]? ?[- ] ?(.*)\.(mp3|ogg)$")
+        tags_capitalize = configboolean("true")
+        tags_stripleadingarticle = configboolean("true")
+        tags_removeaccents = configboolean("true")
         autoregisterer = configboolean("on")
         playingstatslength = configint("100")
-        cachesize = configint("1000")
         server = configstring("")
         port = configint("1972")
 
     class secondary(configsection):
         type = configalternatives("off", ["local", "remote", "off"])
-        basename = configpath("~/.pytone/mp3")
+        basename = configpath("~/.pytone/mp3_2")
+        dbenvdir = configpath("~/.pytone/mp3_2")
         dbfile = configpath("")
+        cachesize = configint("1000")
         musicbasedir = configpath("")
+        tracknrandtitlere = configre(r"^\[?(\d+)\]? ?[- ] ?(.*)\.(mp3|ogg)$")
+        tags_capitalize = configboolean("true")
+        tags_stripleadingarticle = configboolean("true")
+        tags_removeaccents = configboolean("true")
         autoregisterer = configboolean("on")
         playingstatslength = configint("100")
-        cachesize = configint("1000")
         server = configstring("")
         port = configint("1972")
 
@@ -358,6 +375,7 @@ class database(configsection):
 class mixer(configsection):
     device = configpath("/dev/mixer")
     channel = configstring("SOUND_MIXER_PCM")
+    stepsize = configint("5")
 
 class network(configsection):
     enableserver = configboolean("false")
@@ -446,6 +464,10 @@ class logwindow(configsection):
     autoclosetime = configfloat("10")
 
 
+class iteminfolongwindow(configsection):
+    autoclosetime = configfloat("10")
+
+
 class inputwindow(configsection):
     type = configalternatives("popup", ["popup", "statusbar"])
 
@@ -491,7 +513,7 @@ class colors(configsection):
         activeborder = configcolor("color brightgreen mono bold")
         progressbar = configcolor("color cyan cyan")
         border = configcolor("color green")
-        progressbarhigh = configcolor("color red red")
+        progressbarhigh = configcolor("color red red mono bold")
 
     class iteminfowindow(configsection):
         title = configcolor("color brightgreen mono bold")
@@ -501,6 +523,14 @@ class colors(configsection):
         activeborder = configcolor("color brightgreen mono bold")
         border = configcolor("color green")
 
+    class iteminfolongwindow(configsection):
+        title = configcolor("color brightgreen mono bold")
+        content = configcolor("color white")
+        background = configcolor("color white")
+        description = configcolor("color brightcyan mono bold")
+        activeborder = configcolor("color brightgreen mono bold")
+        border = configcolor("color green")
+
     class inputwindow(configsection):
         title = configcolor("color brightgreen mono bold")
         content = configcolor("color white")
@@ -551,6 +581,7 @@ class keybindings(configsection):
         playerstart = configkeys("p P")
         playerpause = configkeys("p P")
         playernextsong = configkeys("n N")
+        playerprevioussong = configkeys("b B")
         playerstop = configkeys("S")
         playlistdeleteplayedsongs = configkeys("KEY_BACKSPACE")
         playlistclear = configkeys("ctrl-d")
@@ -561,6 +592,7 @@ class keybindings(configsection):
         togglelayout = configkeys("KEY_F10")
         showhelp = configkeys("?")
         showlog = configkeys("!")
+        showiteminfolong = configkeys("=")
         volumeup = configkeys(")")
         volumedown = configkeys("(")
 
@@ -580,6 +612,7 @@ class keybindings(configsection):
         insertrandomlist = configkeys("r R")
         rescan = configkeys("u U")
         search = configkeys("/ ctrl-s")
+        repeatsearch = configkeys("ctrl-g")
 
     class playlistwindow(configsection):
         selectnext = configkeys("KEY_DOWN")
@@ -601,8 +634,8 @@ class keybindings(configsection):
 #
 
 sections = ['mixerwindow', 'helpwindow', 'filelistwindow', 'database', 'iteminfowindow',
-            'logwindow', 'mixer', 'colors', 'playerwindow', 'playlistwindow', 'general',
-            'inputwindow', 'network', 'player', 'keybindings']
+            'logwindow', 'iteminfolongwindow', 'mixer', 'colors', 'playerwindow', 'playlistwindow',
+            'general', 'inputwindow', 'network', 'player', 'keybindings']
 
 ##############################################################################
 # end configuration tree
@@ -714,8 +747,11 @@ def usage():
     print "-d, --debug <filename>: enable debugging output (into filename)"
     print "-r, --rebuild: rebuild all databases"
 
+
 def processcommandline():
     try:
+        # keep rest of arguments for other use
+        global args
         opts, args = getopt.getopt(sys.argv[1:],
                                    "hc:d:r",
                                    ["help", "config=", "debug=", "rebuild"])
@@ -755,6 +791,11 @@ def checkoptions():
         print "Please set musicbasedir in the [database.secondary] section of the config file pytonerc\nto the location of your MP3/Ogg Vorbis files."
         sys.exit(2)
 
+    if database.secondary.type=="local" and not (database.secondary.dbfile!="" and database.secondary.basename=="" or
+                                                 database.secondary.dbfile=="" and database.secondary.basename!=""):
+        print "Please use either the dbfile or the basename option (not both) to specify the location of your song database."
+        sys.exit(2)
+
     # check whether oss module is present
     try:
         import ossaudiodev
@@ -763,7 +804,7 @@ def checkoptions():
             import oss
         except:
             mixer.device = ""
-            # helper.debug("disabling mixer since neither ossaudiodev nor oss module is installed\n")
+            # log.debug("disabling mixer since neither ossaudiodev nor oss module is installed")
 
     for aooption in player.main.aooptions.split() + player.secondary.aooptions.split():
         if aooption.count("=")!=1:
