@@ -16,7 +16,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with PyX; if not, write to the Free Software
+# along with PyTone; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import mad
@@ -76,7 +76,6 @@ class decodedsong:
         self.song = song
         self.outrate = outrate
 
-
         if self.song.type=="mp3":
             self.decodedfile = decodedmp3file(song.path)
         elif self.song.type=="ogg":
@@ -137,6 +136,6 @@ class decodedsong:
         oldpos = self.buffpos
         self.buffpos += size
         if self.samplerate:
-            self.ptime += 1.0/4*size/self.samplerate
+            self.ptime += 1.0/4*size/self.outrate
         
         return self.buff[oldpos:self.buffpos]
