@@ -14,13 +14,14 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with PyX; if not, write to the Free Software
+# along with PyTone; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import config
 import item
 import events, hub
 import window
+import messagewin
 
 class iteminfowin(window.window):
     def __init__(self, screen, layout, channel, player):
@@ -32,7 +33,7 @@ class iteminfowin(window.window):
                                _("MP3 Info"), border)
 
         channel.subscribe(events.selectionchanged, self.selectionchanged)
-        channel.subscribe(events.updatesong, self.updatesong)
+        channel.subscribe(events.songchanged, self.songchanged)
 
     def resize(self, layout):
         h, w, y, x, self.border = layout
@@ -88,13 +89,74 @@ class iteminfowin(window.window):
         
     def selectionchanged(self, event):
         if self.player and isinstance(event.item, item.song) and self.item!=event.item:
-            hub.hub.notify(events.nextsong(self.player, event.item))
+            hub.notify(events.nextsong(self.player, event.item))
         self.item = event.item
         self.update()
 
-    def updatesong(self, event):
-        # needed only for songs, since these can be rated when they are played
-        # note that this may update too often (if multiple songdbs are used),
-        # but who cares.
-        if isinstance(self.item, item.song) and event.song==self.item.song:
+    def songchanged(self, event):
+        # needed only for songs, since these can be rated or updated
+        # when they are played note that this may update too often (if
+        # multiple songdbs are used), but who cares.
+        if isinstance(self.item, item.song) and event.songdbid==self.item.songdbid and event.song==self.item.song:
+            self.item.song = event.song
             self.update()
+
+
+class iteminfowinlong(messagewin.messagewin):
+    
+    def __init__(self, screen, maxh, maxw, channel):
+        messagewin.messagewin.__init__(self, screen, maxh, maxw, channel,
+                                       config.colors.iteminfolongwindow,
+                                       _("Item info"), [],
+                                       config.iteminfolongwindow.autoclosetime)
+
+        self.item = None
+
+        channel.subscribe(events.selectionchanged, self.selectionchanged)
+
+    def _outputlen(self, width):
+        return 13
+
+    def showitems(self):
+        # get lines to display
+        empty= [["", "", "", ""]]
+        if self.item:
+            info = self.item.getinfolong()
+        else:
+            info = []
+        l = info + empty*(4-len(info))
+        
+        colsep = self.iw>45
+
+        # calculate width of columns
+        wc1 = 0
+        wc3 = 0
+        for line in info:
+            wc1 = max(wc1, len(line[0]))
+            wc3 = max(wc3, len(line[2]))
+        wc1 += colsep
+        wc3 += colsep
+        wc4 = 10
+        wc2 = self.iw-wc1-wc3-wc4-1
+        self.clear()
+        for lno in range(len(info)):
+            line = l[lno]
+            self.move(1+lno, self.ix)
+            self.addstr(line[0].ljust(wc1)[:wc1], self.colors.description)
+            self.addstr(line[1].ljust(wc2)[:wc2], self.colors.content)
+            self.addch(" ")
+            if lno!=self.ih:
+                self.addstr(line[2].ljust(wc3)[:wc3], self.colors.description)
+                self.addstr(line[3].ljust(wc4)[:wc4], self.colors.content)
+            else:
+                # special handling of last line
+                wc3 = max(len(line[-2]), 5) + colsep
+                wc4 = max(len(line[-1]), 5)
+                
+                self.move(1+lno, self.iw-wc3-wc4-1-self.ix)
+                self.addch(" ")
+                self.addstr(line[-2].ljust(wc3)[:wc3], self.colors.description)
+                self.addstr(line[-1].ljust(wc4)[:wc4], self.colors.content)
+
+    def selectionchanged(self, event):
+        self.item = event.item
