@@ -14,7 +14,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with PyX; if not, write to the Free Software
+# along with PyTone; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 class request:
@@ -55,19 +55,19 @@ class getsong(dbrequest):
 
 
 class getsongs(dbrequest):
-    def __init__(self, songdbid, artist=None, album=None, genre=None, year=None, decade=None, random=None):
+    def __init__(self, songdbid, artist=None, album=None, indexname=None, indexid=None, random=None):
         self.songdbid = songdbid
         self.artist = artist
         self.album = album
-        self.genre = genre
-        self.year = year
-        self.decade = decade
+        self.indexname = indexname
+        self.indexid = indexid
         self.random = random
         
     def __str__(self):
-        return ( "%s(artist=%s, album=%s, genre=%s, year=%s, decade=%s, random=%s)->%s" %
+        return ( "%s(artist=%s, album=%s, index=(%s->%s), random=%s)->%s" %
                  (self.__class__.__name__,
-                  `self.artist`, `self.album`, `self.genre`, `self.year`, `self.decade`,
+                  `self.artist`, `self.album`,
+                  `self.indexname`, `self.indexid`,
                   `self.random`,
                   `self.songdbid`))
 
@@ -80,39 +80,38 @@ class getnumberofdecades(dbrequest):
 class getnumberofgenres(dbrequest):
     pass
 
+class getnumberofratings(dbrequest):
+    pass
+
 class getnumberofalbums(dbrequest):
     pass
 
 class getartists(dbrequest):
-    def __init__(self, songdbid, genre=None, year=None, decade=None):
+    def __init__(self, songdbid, indexname=None, indexid=None):
         self.songdbid = songdbid
-        self.genre = genre
-        self.year = year
-        self.decade = decade
+        self.indexname = indexname
+        self.indexid = indexid
         
     def __str__(self):
-        return "%s(genre=%s, year=%s, decade=%s)->%s" % (self.__class__.__name__,
-                                                         `self.genre`,
-                                                         `self.year`,
-                                                         `self.decade`,
-                                                         `self.songdbid`)
-
+        return "%s(index=(%s->%s))->%s" % (self.__class__.__name__,
+                                           `self.indexname`,
+                                           `self.indexid`,
+                                           `self.songdbid`)
+    
 
 class getalbums(dbrequest):
-    def __init__(self, songdbid, artist=None, genre=None, year=None, decade=None):
+    def __init__(self, songdbid, artist=None, indexname=None, indexid=None):
         self.songdbid = songdbid
         self.artist = artist
-        self.genre = genre
-        self.year = year
-        self.decade = decade
+        self.indexname = indexname
+        self.indexid = indexid
         
     def __str__(self):
-        return "%s(artist=%s, genre=%s, year=%s, decade=%s)->%s" % (self.__class__.__name__,
-                                                                    `self.artist`,
-                                                                    `self.genre`,
-                                                                    `self.year`,
-                                                                    `self.decade`,
-                                                                    `self.songdbid`)
+        return "%s(artist=%s, index(%s->%s))->%s" % (self.__class__.__name__,
+                                                     `self.artist`,
+                                                     `self.indexname`,
+                                                     `self.indexid`,
+                                                     `self.songdbid`)
 
 
 class getalbum(dbrequest):
@@ -145,6 +144,10 @@ class getdecades(dbrequest):
     pass
 
 
+class getratings(dbrequest):
+    pass
+
+
 class getlastplayedsongs(dbrequest):
     # returns a list of tuples (song, playingtime).
     # Due to the different structure of the result compared to the
@@ -208,12 +211,13 @@ class getsongsinplaylists(dbrequest):
 
 
 class requestnextsong(request):
-    """ request a song for player playerid """
-    def __init__(self, playerid):
-        self.playerid = playerid
+    """ request a song from playlistid. Go back in playlist if previous is set """
+    def __init__(self, playlistid, previous=0):
+        self.playlistid = playlistid
+        self.previous = previous
 
     def __str__(self):
-        return "%s->%s" % (self.__class__.__name__, `self.playerid`)
+        return "%s->%s,%s" % (self.__class__.__name__, `self.playlistid`, `self.previous`)
 
 
 class getplaybackinfo(request):
