@@ -1,8 +1,6 @@
 # -*- coding: ISO-8859-1 -*-
 
-# Copyright (C) 2002, 2003 Jrg Lehmann <joerg@luga.de>
-#
-# Ogg Vorbis interface by Byron Ellacott <bje@apnic.net>.
+# Copyright (C) 2002, 2003, 2004 Jrg Lehmann <joerg@luga.de>
 #
 # This file is part of PyTone (http://www.luga.de/pytone/)
 #
@@ -16,7 +14,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with PyX; if not, write to the Free Software
+# along with PyTone; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import events, hub
@@ -31,12 +29,7 @@ def initsongdb(id, config):
     
     if type=="local":
         import songdbs.local
-        songdb = songdbs.local.songdb(id,
-                                      config.basename,
-                                      config.dbfile,
-                                      config.musicbasedir,
-                                      config.playingstatslength,
-                                      config.cachesize)
+        songdb = songdbs.local.songdb(id, config)
     elif type=="remote":
         import songdbs.remote
         songdb = songdbs.remote.songdb(id, config.server, config.port)
@@ -44,7 +37,6 @@ def initsongdb(id, config):
     songdb.setName("song database thread (id=%s)" % id)
     songdb.start()
     if config.autoregisterer:
-        hub.hub.notify(events.autoregistersongs(id))
-            
-        
+        hub.notify(events.autoregistersongs(id))
+
     return id
